
:orphan:

GATK4
=====

Automatically generated index page for GATK4:

.. raw:: html

   <ul>

   </ul>
     <a href="gatk4applybqsr.html">
       <p style="margin-bottom: 5px"><b>GATK4: Apply base quality score recalibration</b> <span style="margin-left: 10px; color: darkgray">Gatk4ApplyBQSR</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4applybqsr.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4baserecalibrator.html">
       <p style="margin-bottom: 5px"><b>GATK4: Base Recalibrator</b> <span style="margin-left: 10px; color: darkgray">Gatk4BaseRecalibrator</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4baserecalibrator.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4calculatecontamination.html">
       <p style="margin-bottom: 5px"><b>GATK4: CalculateContamination</b> <span style="margin-left: 10px; color: darkgray">Gatk4CalculateContamination</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(6 versions)</span><a class="version-button" href="gatk4calculatecontamination.html" style="margin-bottom: 10px">
       v<b>4.1.8.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4collectinsertsizemetrics.html">
       <p style="margin-bottom: 5px"><b>GATK4: CollectInsertSizeMetrics</b> <span style="margin-left: 10px; color: darkgray">Gatk4CollectInsertSizeMetrics</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4collectinsertsizemetrics.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4createsequencedictionary.html">
       <p style="margin-bottom: 5px"><b>GATK4: CreateSequenceDictionary</b> <span style="margin-left: 10px; color: darkgray">Gatk4CreateSequenceDictionary</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(3 versions)</span><a class="version-button" href="gatk4createsequencedictionary.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4depthofcoverage.html">
       <p style="margin-bottom: 5px"><b>GATK4: Generate coverage summary information for reads data</b> <span style="margin-left: 10px; color: darkgray">Gatk4DepthOfCoverage</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="gatk4depthofcoverage.html" style="margin-bottom: 10px">
       v<b>4.1.6.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4fastqtosam.html">
       <p style="margin-bottom: 5px"><b>GATK4: Convert a FASTQ file to an unaligned BAM or SAM file.</b> <span style="margin-left: 10px; color: darkgray">Gatk4FastqToSam</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4fastqtosam.html" style="margin-bottom: 10px">
       v<b>4.1.4.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4filtermutectcalls.html">
       <p style="margin-bottom: 5px"><b>GATK4: GetFilterMutectCalls</b> <span style="margin-left: 10px; color: darkgray">Gatk4FilterMutectCalls</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(6 versions)</span><a class="version-button" href="gatk4filtermutectcalls.html" style="margin-bottom: 10px">
       v<b>4.1.8.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4gatherbqsrreports.html">
       <p style="margin-bottom: 5px"><b>GATK4: GatherBQSRReports</b> <span style="margin-left: 10px; color: darkgray">Gatk4GatherBQSRReports</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4gatherbqsrreports.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4gatherbamfiles.html">
       <p style="margin-bottom: 5px"><b>GATK4: GatherBamFiles</b> <span style="margin-left: 10px; color: darkgray">Gatk4GatherBamFiles</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(3 versions)</span><a class="version-button" href="gatk4gatherbamfiles.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4gathervcfs.html">
       <p style="margin-bottom: 5px"><b>GATK4: Gather VCFs</b> <span style="margin-left: 10px; color: darkgray">Gatk4GatherVcfs</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4gathervcfs.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4genotypeconcordance.html">
       <p style="margin-bottom: 5px"><b>GATK4: Genotype Concordance</b> <span style="margin-left: 10px; color: darkgray">Gatk4GenotypeConcordance</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4genotypeconcordance.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4getpileupsummaries.html">
       <p style="margin-bottom: 5px"><b>GATK4: GetPileupSummaries</b> <span style="margin-left: 10px; color: darkgray">Gatk4GetPileupSummaries</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(6 versions)</span><a class="version-button" href="gatk4getpileupsummaries.html" style="margin-bottom: 10px">
       v<b>4.1.8.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4getpileupsummaries_cram.html">
       <p style="margin-bottom: 5px"><b>GATK4: GetPileupSummaries</b> <span style="margin-left: 10px; color: darkgray">Gatk4GetPileupSummaries_cram</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(6 versions)</span><a class="version-button" href="gatk4getpileupsummaries_cram.html" style="margin-bottom: 10px">
       v<b>4.1.8.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4haplotypecaller.html">
       <p style="margin-bottom: 5px"><b>GATK4: Haplotype Caller</b> <span style="margin-left: 10px; color: darkgray">Gatk4HaplotypeCaller</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(7 versions)</span><a class="version-button" href="gatk4haplotypecaller.html" style="margin-bottom: 10px">
       v<b>4.1.8.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4learnreadorientationmodel.html">
       <p style="margin-bottom: 5px"><b>GATK4: LearnReadOrientationModel</b> <span style="margin-left: 10px; color: darkgray">Gatk4LearnReadOrientationModel</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(6 versions)</span><a class="version-button" href="gatk4learnreadorientationmodel.html" style="margin-bottom: 10px">
       v<b>4.1.8.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4markduplicates.html">
       <p style="margin-bottom: 5px"><b>GATK4: Mark Duplicates</b> <span style="margin-left: 10px; color: darkgray">Gatk4MarkDuplicates</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4markduplicates.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4mergebamalignment.html">
       <p style="margin-bottom: 5px"><b>GATK4: Merge SAM or BAM with unmapped BAM file</b> <span style="margin-left: 10px; color: darkgray">Gatk4MergeBamAlignment</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4mergebamalignment.html" style="margin-bottom: 10px">
       v<b>4.1.4.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4mergemutectstats.html">
       <p style="margin-bottom: 5px"><b>GATK4: MergeMutectStats</b> <span style="margin-left: 10px; color: darkgray">Gatk4MergeMutectStats</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(6 versions)</span><a class="version-button" href="gatk4mergemutectstats.html" style="margin-bottom: 10px">
       v<b>4.1.8.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4mergesamfiles.html">
       <p style="margin-bottom: 5px"><b>GATK4: Merge SAM Files</b> <span style="margin-left: 10px; color: darkgray">Gatk4MergeSamFiles</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4mergesamfiles.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4mutect2.html">
       <p style="margin-bottom: 5px"><b>GatkMutect2</b> <span style="margin-left: 10px; color: darkgray">Gatk4Mutect2</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(7 versions)</span><a class="version-button" href="gatk4mutect2.html" style="margin-bottom: 10px">
       v<b>4.1.8.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4mutect2_cram.html">
       <p style="margin-bottom: 5px"><b>GatkMutect2</b> <span style="margin-left: 10px; color: darkgray">Gatk4Mutect2_cram</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(6 versions)</span><a class="version-button" href="gatk4mutect2_cram.html" style="margin-bottom: 10px">
       v<b>4.1.8.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4printreads.html">
       <p style="margin-bottom: 5px"><b>GATK4: Print Reads</b> <span style="margin-left: 10px; color: darkgray">Gatk4PrintReads</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4printreads.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4selectvariants.html">
       <p style="margin-bottom: 5px"><b>GATK4: SelectVariants</b> <span style="margin-left: 10px; color: darkgray">Gatk4SelectVariants</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4selectvariants.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4setnmmdanduqtags.html">
       <p style="margin-bottom: 5px"><b>GATK4: SetNmMdAndUqTags</b> <span style="margin-left: 10px; color: darkgray">Gatk4SetNmMdAndUqTags</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="gatk4setnmmdanduqtags.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4sortsam.html">
       <p style="margin-bottom: 5px"><b>GATK4: SortSAM</b> <span style="margin-left: 10px; color: darkgray">Gatk4SortSam</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4sortsam.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4splitreads.html">
       <p style="margin-bottom: 5px"><b>GATK4: SplitReads</b> <span style="margin-left: 10px; color: darkgray">Gatk4SplitReads</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(3 versions)</span><a class="version-button" href="gatk4splitreads.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4variantfiltration.html">
       <p style="margin-bottom: 5px"><b>GATK4: VariantFiltration</b> <span style="margin-left: 10px; color: darkgray">Gatk4Variantfiltration</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatk4variantfiltration.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatkaddorreplacereadgroups.html">
       <p style="margin-bottom: 5px"><b>Gatk4: AddOrReplaceReadGroups</b> <span style="margin-left: 10px; color: darkgray">GatkAddOrReplaceReadGroups</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatkaddorreplacereadgroups.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatkreordersam.html">
       <p style="margin-bottom: 5px"><b>Gatk4: ReorderSam</b> <span style="margin-left: 10px; color: darkgray">GatkReorderSam</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="gatkreordersam.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatksplitncigarreads.html">
       <p style="margin-bottom: 5px"><b>GATK4: SplitNCigarReads</b> <span style="margin-left: 10px; color: darkgray">GatkSplitNCigarReads</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(4 versions)</span><a class="version-button" href="gatksplitncigarreads.html" style="margin-bottom: 10px">
       v<b>4.1.4.0</b>
     </a></p>
     </a>
     <hr />
         

